import { select, 
         json, 
         geoPath, 
         geoMercator,
       	 interpolateOranges, 
       	 scaleSequentialLog,
         scaleLog
       } from 'd3';
// import { legend } from '@d3/color-legend';
import { feature } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';

const svg = select('svg');

const choroplethMapG = svg.append('g');

const projection = geoMercator()
	.center([105, 43])
	.scale([820]);
const pathGenerator = geoPath().projection(projection);

let features;
let maxTotalCases;

const colorValue = d => Math.log(d) / Math.log(maxTotalCases);

loadAndProcessData().then(countries => {
	features = countries.features;
  maxTotalCases = features.reduce((accumulator, d) => {
                    accumulator = (accumulator < +d.properties.T_C_0621
                                  && d.properties.T_C_0621 !== 'NA') ?
                                  +d.properties.T_C_0621 :
                                  accumulator;
    								return accumulator;
									}, 0)
  render();
});

const render = () => {
  
  const colorScale = scaleLog()
  	.domain([0, maxTotalCases])
  	.interpolator(interpolateOranges);
  
  console.log(colorScale(100));
  
	choroplethMapG.selectAll('path')
    .data(features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => {
    		let cases = d.properties.T_C_0621;
    		if (cases === 'NA' || cases === undefined) {
        	return '#636363';
        } else {
        	cases = +cases;
        	return cases === 0 ? 
            interpolateOranges(0) :
            interpolateOranges(colorValue(cases));
        }
  		})
};

